==> babel-plugin-dynamic-i18n-0.1.0.tgz: package/README.md <==
# babel-plugin-dynamic-i18n

[![campai](https://user-images.githubusercontent.com/2905403/36994178-8c5087fe-20b0-11e8-8905-f2062939eb6b.png)](https://www.campai.com)

## Basic Overview

babel-plugin-dynamic-i18n is a small and powerful plugin to generate localization/internationalization files.

    - Use an alias for a function that receives a string as parameter in your code
    - Configure the plugin with own options
    - During code compilation, get your function observed and strings mapped
    - Get a JSON file with key/value of the strings used in your code
    - Have your localization files ready for translation

## How it works

Babel is a JavaScript compiler, specifically a source-to-source compiler, often called a "transpiler". This means that you give Babel some JavaScript code, Babel modifies the code, and generates the new code back out.

babel-plugin-dynamic-i18n is mostly an observer of the alias function usage in the source code and, as a side-effect, creates new localization files.

This plugin is able to generate one or multiple JSON files, language specific, with the strings used in your source code.

## Example

### Input
- Source javascript file, regular string with alias function __ (double underscore)
```
    <StyledSpan>{__('A really important string')}</StyledSpan>
```

### Output
- Localization file with the key/value mapped. Alternatively, include a tag to not forget the translation.
```
    {
        "A really important string": "A really important string// TODO"
    }
```

## Getting Started

If you want to work with babel-plugin-dynamic-i18n, you can add it to your project as a [node](https://nodejs.org/en/) dependency, using a node package manager as [npm](https://www.npmjs.com/) or [yarn](https://yarnpkg.com/).

### Installing

From the root folder of your project:

```
$ npm install --save-dev babel-plugin-dynamic-i18n
```

or, alternatively:

```
$ yarn add babel-plugin-dynamic-i18n
```

### Usage

#### Via .babelrc (Recommended)

```
{
  "plugins": ["babel-plugin-dynamic-i18n", options = {}]
}
```

#### Via CLI

```
babel --plugins babel-plugin-dynamic-i18n index.js
```

#### Plugin Options
- Must be an object with some attributes.
```
{
    alias: '__', // plugin observes the usage of this function
    todoTag: '// TODO', // tag to be added in the value of the strings
    outputPath: '/languages', // write new localization files
    languages: ['de', 'ch', 'pt'] // each language generate a new output file
}
```

## Versions

babel-plugin-dynamic-i18n is always under development and improvements. It's possible to check each release version and the improvements/modifications below.

| Release | What's new? |
| ------ | ------ |
| 0.1.0 | Generate files for each language in configs |

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

==> babel-plugin-dynamic-i18n-0.1.1.tgz: package/README.md <==
# babel-plugin-dynamic-i18n

[![campai](https://user-images.githubusercontent.com/2905403/36994178-8c5087fe-20b0-11e8-8905-f2062939eb6b.png)](https://www.campai.com)

## Basic Overview

babel-plugin-dynamic-i18n is a small and powerful plugin to generate localization/internationalization files.

    - Use an alias for a function that receives a string as parameter in your code
    - Configure the plugin with own options
    - During code compilation, get your function observed and strings mapped
    - Get a JSON file with key/value of the strings used in your code
    - Have your localization files ready for translation

## How it works

Babel is a JavaScript compiler, specifically a source-to-source compiler, often called a "transpiler". This means that you give Babel some JavaScript code, Babel modifies the code, and generates the new code back out.

babel-plugin-dynamic-i18n is mostly an observer of the alias function usage in the source code and, as a side-effect, creates new localization files.

This plugin is able to generate one or multiple JSON files, language specific, with the strings used in your source code.

## Example

### Input
- Source javascript file, regular string with alias function __ (double underscore)
```
    <StyledSpan>{__('A really important string')}</StyledSpan>
```

### Output
- Localization file with the key/value mapped. Alternatively, include a tag to not forget the translation.
```
    {
        "A really important string": "A really important string// TODO"
    }
```

## Getting Started

If you want to work with babel-plugin-dynamic-i18n, you can add it to your project as a [node](https://nodejs.org/en/) dependency, using a node package manager as [npm](https://www.npmjs.com/) or [yarn](https://yarnpkg.com/).

### Installing

From the root folder of your project:

```
$ npm install --save-dev babel-plugin-dynamic-i18n
```

or, alternatively:

```
$ yarn add babel-plugin-dynamic-i18n
```

### Usage

#### Via .babelrc (Recommended)

```
{
  "plugins": ["babel-plugin-dynamic-i18n", options = {}]
}
```

#### Via CLI

```
babel --plugins babel-plugin-dynamic-i18n index.js
```

#### Plugin Options
- Must be an object with some attributes.
```
{
    outputPath: '/languages', // write new localization files
    todoTag: '// TODO', // tag to be added in the value of the strings, default // TODO
    alias: '__', // plugin observes the usage of this function, default __ (double underscore)
    language: ['de', 'ch', 'pt'] // each language generate a new output file, can be a single string,
    replaceInline: false, // if compiled code should have the key replaced by it's value, default false
}
```

The code itself has more information about the current flow and usage.

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details
